#############################################################
#############################################################
####################UNIFRAC BAT + ENVIRO ####################

#Loading packages
library("vegan")
library("phyloseq")
library("ggplot2")
library("ade4")
library("ape")


#Color-blind color scheme
cbbPalette <- c("#000000", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")


#Create phyloseq object
otu_table_Bat_1 = import_biom("~/Desktop/Outaouais_Manitoba_2016_unique.dbOTU.nonchimera.matTAX.biom")
mapping_file_Bat_2 = import_qiime_sample_data("~/Desktop/Mapping_Bat_enviro_2samples_only.txt")
tree_file_Bat_1 = read_tree_greengenes("~/Desktop/Outa_Manit_2016_Tree")
Bat_OTUs_Env = merge_phyloseq(otu_table_Bat_1,mapping_file_Bat_2,tree_file_Bat_1)


# Prune OTUs count less than 3
Batprune_Env = prune_taxa(taxa_sums(Bat_OTUs_Env) > 3, Bat_OTUs_Env)
Batprune_Env
#Rarefy at even depth 9898 seqs/sample
Batprune_Env=rarefy_even_depth(Batprune_Env)
#Checking rarefying
sample_sums(Batprune_Env)[1:10]




##########################################
###PCOA unweighted UniFrac bat + enviro###

#plot options
pt=geom_point(size = 4.5)
label=theme(legend.text = element_text(size = 16))
legendtitle=theme(legend.title = element_text(size=18))

#Unweighted UniFrac
distunifracunw_env = phyloseq::distance(Batprune_Env, "unifrac",weighted=FALSE)
is.euclid(distunifracunw_env) #TRUE: no transformation required for PCOA

#Unweighted UniFrac PCOA
PCOA_distunifrac_env_unw= ordinate(Batprune_Env, "PCoA", distunifracunw_env)
Plotdistunifrac_env_unw<-plot_ordination(Batprune_Env, PCOA_distunifrac_env_unw, type = "samples", color = "Sites", shape= "Type") + scale_shape_manual(values = c(17,15))
PLot_final_unif_env=Plotdistunifrac_env_unw+ scale_color_manual(values = c("#CC79A7", "#E69F00", "#56B4E9","#009E73", "#0072B2", "#D55E00")) + theme_bw() + theme(plot.background = element_blank() ,panel.grid.minor = element_blank() ,panel.background = element_blank(), axis.title.x = element_text(color="black", size=14), axis.title.y = element_text(color="black", size=14))

Plot_PCOA_final_unif_env= PLot_final_unif_env+pt+label+legendtitle
Plot_PCOA_final_unif_env

#Ordering legend
order=scale_color_hue(breaks=c("Abyss","Dales","Microwave", "Emerald", "Lafleche", "Lames"))
Final_plot=Plot_PCOA_final_unif_env+order






########################################
###PCOA weighted UniFrac bat + enviro###

#Weighted UniFrac
distunifrac_env = phyloseq::distance(Batprune_Env, "unifrac",weighted=TRUE)
is.euclid((distunifrac_env))#FALSE
#square-root transformations to obtain distance matrices satisfying the Euclidian condition
sqrt_distunifrac_env=sqrt(distunifrac_env)

#Weighted UniFrac PCOA
PCOA_distunifrac_env= ordinate(Batprune_Env, "PCoA", sqrt_distunifrac_env)
Plotdistunifrac_env<-plot_ordination(Batprune_Env, PCOA_distunifrac_env, type = "samples", color = "Sites", shape= "Type")+ scale_shape_manual(values = c(17,15))
PLot_final_unifW_env=Plotdistunifrac_env+ scale_color_manual(values = c("#CC79A7", "#E69F00", "#56B4E9","#009E73", "#0072B2", "#D55E00")) + theme_bw() + theme(plot.background = element_blank() ,panel.grid.minor = element_blank() ,panel.background = element_blank(), axis.title.x = element_text(color="black", size=14), axis.title.y = element_text(color="black", size=14))

Plot_PCOA_final_unifW_env= PLot_final_unifW_env+pt+label+legendtitle

#Ordering legend
order2=scale_color_hue(breaks=c("Abyss","Dales","Microwave", "Emerald", "Lafleche", "Lames"))

Plot_PCOA_final_unifW_env=Plot_PCOA_final_unifW_env+order2


#2 panels figure
library("Rmisc")
multiplot(Final_plot, Plot_PCOA_final_unifW_env, cols=1)







#############################################################
#############################################################
############DbRDA unweighted UniFrac bat enviro##############

#Import explanatory table sites hibernacula
Matrix_hibernacula=read.table("~/Desktop/Enviro2samples_Bat_Hibernacula.txt")
Matrix_hibernacula=as.data.frame(Matrix_hibernacula)

#dbRDA unweighted hibernacula
dbRDAhibernacula_env=capscale(distunifracunw_env~., Matrix_hibernacula)
dbRDAhibernacula_env
anova.cca(dbRDAhibernacula_env, permutations=9999)
#F=4.3457 P=1e-04
RsquareAdj(dbRDAhibernacula_env)
#R2adj=0.1804021


#Import explanatory table type
Matrix_type=read.table("~/Desktop/Enviro2samples_Bat_type.txt")
Matrix_type=as.data.frame(Matrix_type)

#dbRDA unweighted UniFrac type
dbRDA_env_type=capscale(distunifracunw_env~., Matrix_type)
dbRDA_env_type
anova.cca(dbRDA_env_type, permutations=9999)
#F=4.7786  P=1e-04
RsquareAdj(dbRDA_env_type)
#R2adj=0.04736343


##############################################################
#########dbRDA partial unweighted UniFrac#####################

bind_all_bat_env=cbind(Matrix_type,Matrix_hibernacula)

#dbRDA unweighted UniFrac sites hibernacula partial out type#
par.dbRDA_hibernacula_type=capscale(distunifracunw_env~ Emerald + Abyss + Dales + Lafleche + Lames + Microwave + Condition(Type), bind_all_bat_env)
par.dbRDA_hibernacula_type
anova.cca(par.dbRDA_hibernacula_type, permutations=9999)
#F=4.822 P=1e-04
RsquareAdj(par.dbRDA_hibernacula_type)
#R2adj=  0.1934441

#dbRDA unweighted UniFrac type partial out sites hibernacula##
par.dbRDA_type_hibernacula=capscale(distunifracunw_env~ Type+Condition(Emerald + Abyss + Dales + Lafleche + Lames + Microwave), bind_all_bat_env)
par.dbRDA_type_hibernacula
anova.cca(par.dbRDA_type_hibernacula, permutations=9999)
#F=6.6491 P=1e-04
RsquareAdj(par.dbRDA_type_hibernacula)
#R2adj=  0.06040551







##############################################################
##############################################################
##############dbRDA weighted UniFrac##########################

#dbRDA weighted UniFrac sites hibernacula#
WdbRDAhibernacula_env=capscale(sqrt_distunifrac_env~., Matrix_hibernacula)
WdbRDAhibernacula_env
anova.cca(WdbRDAhibernacula_env, permutations=9999)
#F=4.2544 p=1e-04
RsquareAdj(WdbRDAhibernacula_env)
#R2adj=0.1763498

#dbRDA weighted UniFrac type#
type_WdbRDAhibernacula_env=capscale(sqrt_distunifrac_env~., Matrix_type)
type_WdbRDAhibernacula_env
anova.cca(type_WdbRDAhibernacula_env, permutations=9999)
#F=7.1866 p=1e-04
RsquareAdj(type_WdbRDAhibernacula_env)
#R2adj=0.07527486




##############################################################
#############DbRDA partial weighted Unifrac###################

#dbRDA weighted UniFrac sites hibernacula partial out type#
Par.WdbRDAhibernacula_env_type=capscale(sqrt_distunifrac_env~ Emerald + Abyss + Dales + Lafleche + Lames + Microwave + Condition(Type),bind_all_bat_env)
Par.WdbRDAhibernacula_env_type
anova.cca(Par.WdbRDAhibernacula_env_type, permutations=9999)
#F=4.8584 p=1e-04
RsquareAdj(Par.WdbRDAhibernacula_env_type)
#R2adj=0.1891989


#dbRDA weighted UniFrac type partial out sites hibernacula##
Par.WdbRDAtype_env_hibernacula=capscale(sqrt_distunifrac_env~ Type+ Condition(Emerald + Abyss + Dales + Lafleche + Lames + Microwave),bind_all_bat_env)
Par.WdbRDAtype_env_hibernacula
anova.cca(Par.WdbRDAtype_env_hibernacula, permutations=9999)
#F=9.5066 p=1e-04
RsquareAdj(Par.WdbRDAtype_env_hibernacula)
#R2adj=0.08812404

