#############################################################
#############################################################
##################UNIFRAC BAT ONLY###########################

#Loading packages
library("vegan")
library("phyloseq")
library("ggplot2")
library("ade4")
library("ape")

#Color-blind color scheme
cbbPalette <- c("#000000", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")

#Create phyloseq object
otu_table_Bat_1 = import_biom("~/Desktop/Outaouais_Manitoba_2016_unique.dbOTU.nonchimera.matTAX.biom")
mapping_file_Bat_1 = import_qiime_sample_data("~/Desktop/Mapping_bat_only.txt")
tree_file_Bat_1 = read_tree_greengenes("~/Desktop/Outa_Manit_2016_Tree")
Bat_OTUs_1 = merge_phyloseq(otu_table_Bat_1,mapping_file_Bat_1,tree_file_Bat_1)


# Prune OTUs count less than 3
Batprune = prune_taxa(taxa_sums(Bat_OTUs_1) > 3, Bat_OTUs_1)
Batprune
#Rarefy at even depth 9886 seqs/sample
Batprune=rarefy_even_depth(Batprune)
#Checking rarefying
sample_sums(Batprune)[1:10]


##########################################
######PCOA unweighted UniFrac ############

#plot options
pt=geom_point(size = 4.5)
label=theme(legend.text = element_text(size = 16))
legendtitle=theme(legend.title = element_text(size=18))
legendorder=scale_color_hue(breaks=c("Abyss","Dales","Microwave", "Emerald", "Lafleche", "Lames"))
legendtop=guides(color = guide_legend(order=2),
shape = guide_legend(order=1))

#Unweighted UniFrac
Unifrac=phyloseq::distance(Batprune, "unifrac",weighted=FALSE)
is.euclid(Unifrac)#TRUE

#Unweighted UniFrac PCOA
PCOA_Unifrac=ordinate(Batprune, "PCoA", Unifrac)
Plot_PCoA_Unifrac=plot_ordination(Batprune, PCOA_Unifrac, type = "samples", color = "Sites", shape= "WNS") + scale_shape_manual(values = c(18,20))
Plot_PCOA_bat=Plot_PCoA_Unifrac+ scale_color_manual(values = c("#CC79A7", "#E69F00", "#56B4E9","#009E73", "#0072B2", "#D55E00")) + theme_bw() + theme(plot.background = element_blank() ,panel.grid.minor = element_blank() ,panel.background = element_blank(), axis.title.x = element_text(color="black", size=14), axis.title.y = element_text(color="black", size=14))
Plot_pcoa_bat_final=Plot_PCOA_bat+pt+label+legendtitle+legendorder+legendtop



#####################################
######PCOA weighted UniFrac #########

#Weighted UniFrac
WUnifrac=phyloseq::distance(Batprune, "unifrac", weighted=TRUE)
is.euclid(WUnifrac)
#square-root transformations to obtain distance matrices satisfying the Euclidian condition
sqrt_distunifrac=sqrt(WUnifrac)
is.euclid(sqrt_distunifrac)#TRUE

#Weighted UniFrac PCOA
WPCOA_Unifrac=ordinate(Batprune, "PCoA", sqrt(WUnifrac))
WPlot_PCoA_Unifrac=plot_ordination(Batprune, WPCOA_Unifrac, type = "samples", color = "Sites", shape= "WNS") + scale_shape_manual(values = c(18,20))
WPlot_PCOA_bat=WPlot_PCoA_Unifrac+ scale_color_manual(values = c("#CC79A7", "#E69F00", "#56B4E9","#009E73", "#0072B2", "#D55E00")) + theme_bw() + theme(plot.background = element_blank() ,panel.grid.minor = element_blank() ,panel.background = element_blank(), axis.title.x = element_text(color="black", size=14), axis.title.y = element_text(color="black", size=14))
WPlot_pcoa_bat_final=WPlot_PCOA_bat+pt+label+legendtitle+legendorder+legendtop

#2 panels figure
library("Rmisc")
multiplot(Plot_pcoa_bat_final, WPlot_pcoa_bat_final, cols=1)




#############################################################
#############################################################
#######dbRDA UniFrac unweighted bat##########################


##dbRDA WNS model##
#Import WNS explanatory table
Matrix_WNS=read.table("~/Desktop/Bat_WNS.txt")
Matrix_WNS=as.data.frame(Matrix_WNS)

#dbRDA WNS model
dbRDAWNS=capscale(Unifrac~., Matrix_WNS)
dbRDAWNS
anova.cca(dbRDAWNS, permutations=9999)
#F=7.0354  P=1e-04
RsquareAdj(dbRDAWNS)
#R2adj=0.08496348



##dbRDA sites hibernacula model##
#Import explanatory table sites hibernacula
Matrix_hibernacula=read.table("~/Desktop/Bat_hibernacula.txt")
Matrix_hibernacula=as.data.frame(Matrix_hibernacula)

#dbRDA sites hibernacula model
dbRDAhibernacula=capscale(Unifrac~., Matrix_hibernacula)
dbRDAhibernacula
anova.cca(dbRDAhibernacula, permutations=9999)
#F=4.6754  P=1e-04
RsquareAdj(dbRDAhibernacula)
#R2adj=0.2204082



##dbRDA cluster model##
#Import explanable variable matrix
Matrix_cluster=read.table("~/Desktop/Bat_cluster.txt")
Matrice_cluster=as.data.frame(Matrix_cluster)

#dbRDA cluster model
dbRDAcluster_bat=capscale(Unifrac~., Matrix_cluster)
dbRDAcluster_bat
anova.cca(dbRDAcluster_bat, permutations=9999)
#F=2.9829  P=1e-04
RsquareAdj(dbRDAcluster_bat)
#R2adj=0.2839656






##############################################################
#########dbRDA partial unweighted UniFrac#####################

#Merge explanatory tables
bind_all_bat=cbind(Matrix_cluster,Matrix_hibernacula, Matrix_WNS)

##dbRDA sites hibernacula partial out cluster##
dbRDAhibernacula_par_cluster=capscale(Unifrac~Emerald+Abyss+Dales+Lafleche+Lames+Microwave +Condition(Cluster1 + Cluster2 + Cluster3 + Cluster4 + Cluster5 + Cluster6 + Cluster7 + Cluster8 + Cluster9 + Cluster10 + Cluster11 + Cluster12 + Cluster13 + Cluster14), data = bind_all_bat)
dbRDAhibernacula_par_cluster
anova.cca(dbRDAhibernacula_par_cluster, permutations=9999)
#F=0  P=00 
RsquareAdj(dbRDAhibernacula_par_cluster)
#R2adj=0


##dbRDA sites hibernacula partial out WNS##
par.dbRDA.Hibernacula_WNS=capscale(Unifrac~Emerald+Abyss+Dales+Lafleche+Lames+Microwave +Condition(WNSPos), data = bind_all_bat)
par.dbRDA.Hibernacula_WNS
anova.cca(par.dbRDA.Hibernacula_WNS, permutations=9999)
#F=3.7798  P= 1e-04
RsquareAdj(par.dbRDA.Hibernacula_WNS)
#=0.1354447

##dbRDA WNS partial out sites hibernacula##
par.dbRDA.WNS_Hibernacula=capscale(Unifrac~WNSPos+Condition(Emerald+Abyss+Dales+Lafleche+Lames+Microwave), data = bind_all_bat)
par.dbRDA.WNS_Hibernacula
anova.cca(par.dbRDA.WNS_Hibernacula, permutations=9999)
#F=0  P=0
RsquareAdj(par.dbRDA.WNS_Hibernacula)
#=0

##dbRDA WNS partial out cluster##
par.dbRDA.WNS.Cluster=capscale(Unifrac~WNSPos+ Condition(Cluster1 + Cluster2 + Cluster3 + Cluster4 + Cluster5 + Cluster6 + Cluster7 + Cluster8 + Cluster9 + Cluster10 + Cluster11 + Cluster12 + Cluster13 + Cluster14), data = bind_all_bat)
par.dbRDA.WNS.Cluster
anova.cca(par.dbRDA.WNS.Cluster, permutations=9999)
#F=0  P=0
RsquareAdj(par.dbRDA.WNS.Cluster)
#=0

##dbRDA cluster partial out sites hibernacula##
dbRDA.cluster_par_hibernacula=capscale(Unifrac~Cluster1 + Cluster2 + Cluster3 + Cluster4 + Cluster5 + Cluster6 + Cluster7 + Cluster8 + Cluster9 + Cluster10 + Cluster11 + Cluster12 + Cluster13 + Cluster14+Condition(Emerald+Abyss+Dales+Lafleche+Lames+Microwave), data = bind_all_bat)
dbRDA.cluster_par_hibernacula
anova.cca(dbRDA.cluster_par_hibernacula, permutations=9999)
#F= 1.6676 P=1e-04
RsquareAdj(dbRDA.cluster_par_hibernacula)
#R2adj=0.06373466

##dbRDA cluster partial out WNS##
dbRDA.cluster_par_WNS=capscale(Unifrac~Cluster1 + Cluster2 + Cluster3 + Cluster4 + Cluster5 + Cluster6 + Cluster7 + Cluster8 + Cluster9 + Cluster10 + Cluster11 + Cluster12 + Cluster13 + Cluster14+Condition(WNSPos),data = bind_all_bat)
dbRDA.cluster_par_WNS
anova.cca(dbRDA.cluster_par_WNS, permutations=9999)
#F= 2.4813 P=1e-04
RsquareAdj(dbRDA.cluster_par_WNS)
#R2adj= 0.1988714










#############################################################
#############################################################
#############dbRDA weighted UniFrac##########################



##dbRDA WNS##
W.WNS=capscale(sqrt_distunifrac~.,Matrix_WNS)
W.WNS
anova.cca(W.WNS, permutations=9999)
#F=11.7    P=1e-04
RsquareAdj(W.WNS)
#R2adj=0.1413491


#dbRDA sites hibernacula##
WdbRDAhibernacula=capscale(sqrt_distunifrac~., Matrix_hibernacula)
WdbRDAhibernacula
anova.cca(WdbRDAhibernacula, permutations=9999)
#F=5.4543  P=1e-04
RsquareAdj(WdbRDAhibernacula)
#R2adj=0.2551959


##dbRDA cluster##
WdbRDAcluster=capscale(sqrt_distunifrac~., Matrix_cluster)
WdbRDAcluster
anova.cca(WdbRDAcluster, permutations=9999)
#F=3.1833  P=1e-04
RsquareAdj(WdbRDAcluster)
#R2adj=0.3039367




#############################################################
#############dbRDA partial weighted UniFrac##################

##dbRDA weighted UniFrac WNS partial out sites hibernacula##
WdbRDAProvince_WNS_par_hibernacula=capscale(sqrt_distunifrac~WNSPos+Condition(Emerald+Abyss+Dales+Lafleche+Lames+Microwave), data = bind_all_bat)
WdbRDAProvince_WNS_par_hibernacula
anova.cca(WdbRDAProvince_WNS_par_hibernacula, permutations=9999)
#F=0  P=0.000
RsquareAdj(WdbRDAProvince_WNS_par_hibernacula)
#R2adj= 0


##dbRDA weighted UniFrac WNS partial out cluster##
WdbRDA_WNS_par_Cluster=capscale(sqrt_distunifrac~WNSPos+ Condition(Cluster1 + Cluster2 + Cluster3 + Cluster4 + Cluster5 + Cluster6 + Cluster7 + Cluster8 + Cluster9 + Cluster10 + Cluster11 + Cluster12 + Cluster13 + Cluster14), data = bind_all_bat)
WdbRDA_WNS_par_Cluster
anova.cca(WdbRDA_WNS_par_Cluster, permutations=9999)
#F=0  P=0.000
RsquareAdj(WdbRDA_WNS_par_Cluster)
#R2adj= 0


##dbRDA weighted UniFrac sites hibernacula partial out WNS##
WdbRDAhibernacula_par_WNS=capscale(sqrt_distunifrac~ Emerald+Abyss+Dales+Lafleche+Lames+Microwave +Condition(WNSPos), data = bind_all_bat)
WdbRDAhibernacula_par_WNS
anova.cca(WdbRDAhibernacula_par_WNS, permutations=9999)
#F=3.4457 P= 1e-04
RsquareAdj(WdbRDAhibernacula_par_WNS)
# R2adj=0.1138468


##dbRDA weighted UniFrac sites hibernacula partial out cluster##
WdbRDAhibernacula_par_Cluster=capscale(sqrt_distunifrac~ Emerald+Abyss+Dales+Lafleche+Lames+Microwave +Condition(Cluster1 + Cluster2 + Cluster3 + Cluster4 + Cluster5 + Cluster6 + Cluster7 + Cluster8 + Cluster9 + Cluster10 + Cluster11 + Cluster12 + Cluster13 + Cluster14), data = bind_all_bat)
WdbRDAhibernacula_par_Cluster
anova.cca(WdbRDAhibernacula_par_Cluster, permutations=9999)
#F=0  P=0
RsquareAdj(WdbRDAhibernacula_par_Cluster)
# R2adj=0


##dbRDA weighted UniFrac cluster partial out WNS##
WdbRDACluster_par_WNS=capscale(sqrt_distunifrac~Cluster1 + Cluster2 + Cluster3 + Cluster4 + Cluster5 + Cluster6 + Cluster7 + Cluster8 + Cluster9 + Cluster10 + Cluster11 + Cluster12 + Cluster13 + Cluster14+Condition(WNSPos),data = bind_all_bat)
WdbRDACluster_par_WNS
anova.cca(WdbRDACluster_par_WNS, permutations=9999)
#F=2.2433 P=1e-04
RsquareAdj(WdbRDACluster_par_WNS)
# R2adj=0.1622607


##dbRDA weighted UniFrac cluster partial out site hibernacula##
WdbRDACluster_par_hibernacula=capscale(sqrt_distunifrac~ Cluster1 + Cluster2 + Cluster3 + Cluster4 + Cluster5 + Cluster6 + Cluster7 + Cluster8 + Cluster9 + Cluster10 + Cluster11 + Cluster12 + Cluster13 + Cluster14+Condition(Emerald+Abyss+Dales+Lafleche+Lames+Microwave), data = bind_all_bat)
WdbRDACluster_par_hibernacula
anova.cca(WdbRDACluster_par_hibernacula, permutations=9999)
#F=1.5286 P= 3e-04
RsquareAdj(WdbRDACluster_par_hibernacula)
# R2adj=0.04905915










