###################################
####IndVal#########################


#Indicator value indices are used for assessing the predictive values of species as indicators of the conditions
#prevailing in site groups, e.g. for field determination of community types or ecological monitoring

##Load packages
library(indicspecies)

#Read the package vignette to learn how to use this package
vignette("indicspeciesTutorial", package="indicspecies")

#Import OTUs table of the 26 more abundant OTUS
batl6 = read.table("$path/Genus_26abun_no_ha_shewa_IndVal_Bat.txt", fill=TRUE, header=TRUE, row.names = 1)
batmat=as.matrix(batl6)

#Transform count table to relative abundance table
library(vegetarian)
batrel=normalize.rows(batl6)
bindrel=cbind(batrel,batl6[,0])
f=batl6[0,]
colnames(bindrel)=colnames(f)


###################################
#IndVal hibernacula #

#Create group by sites hibernacula
vecbat= c(rep(1,11),rep(2,11),rep(3,11),rep(4,11),rep(5,11),rep(6,11))
#Indicator Value analysis
indval.hibernacula = multipatt(bindrel, vecbat, func = "IndVal", duleg=TRUE, control = how(nperm=9999))
summary(indval.hibernacula, indvalcomp=TRUE)
#Correction for multiple testing
holmprob = p.adjust(indval.hibernacula$sign$p.value, "holm")
holmprob
#Table with corrected p.value
Indval.hibernacula.p.holm=cbind(indval.hibernacula$sign,holmprob)


###################################
#IndVal WNS#
#Create group by WNS status
vecbat.WNS=c(rep(1,11),rep(2,11),rep(2,11),rep(1,11),rep(1,11),rep(2,11))
#Indicator Value analysis
indval.out.WNS=multipatt(bindrel, vecbat.WNS, func = "IndVal", duleg=TRUE, control = how(nperm=9999))
summary(indval.out.WNS, indvalcomp=TRUE)
#Inspect the indicator value components when displaying the results
summary(indval.out.WNS, indvalcomp=TRUE)
#Correction for multiple testing
holmprob.WNS = p.adjust(indval.out.WNS$sign$p.value, "holm")
holmprob.WNS
#Table with corrected p.value
Indval.WNS.p.holm=cbind(indval.out.WNS$sign,holmprob.WNS)





